package es.androidcurso.timetracker;

import android.app.Activity;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.opengl.Visibility;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import es.androidcurso.timetracker.entities.Project;
import es.androidcurso.timetracker.entities.Task;
import es.androidcurso.timetracker.sqlite.TimeTrackerHelper;

public class AddTaskActivity extends Activity implements View.OnClickListener {

    private TimeTrackerHelper timeTrackerHelper;
    private EditText titleEditTExt;
    private EditText descriptionEditText;

    private Task task;
    private boolean executing;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        getActionBar().setDisplayShowTitleEnabled(false);
        getActionBar().setDisplayShowHomeEnabled(false);
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_add_task);
        timeTrackerHelper = new TimeTrackerHelper(this);

        titleEditTExt = (EditText) findViewById(R.id.editTitleId);
        descriptionEditText = (EditText) findViewById(R.id.editDescriptionId);

        task = getIntent().getParcelableExtra("task");

        Button executeButton = (Button) findViewById(R.id.buttonExecuteTask);

        if(null != task){
            TextView title = (TextView) findViewById(R.id.newTaskTextId);
            title.setText("Editar tarea");
            Button button = (Button) findViewById(R.id.buttonRegisterId);
            button.setText("Modificar");
            titleEditTExt.setText(task.getTitle());
            descriptionEditText.setText(task.getDescription());
            executeButton.setText("Iniciar");
            Drawable icon  = this.getResources().getDrawable(R.drawable.play);
            executing = timeTrackerHelper.isTaskExecuting(task.getIdTask());
            if(executing){
                icon = this.getResources().getDrawable(R.drawable.stop);
                executeButton.setText("Parar");
            }
            executeButton.setCompoundDrawablesWithIntrinsicBounds(icon, null, null, null);
            executeButton.setOnClickListener(this);
        }else{
            executeButton.setVisibility(View.INVISIBLE);
        }
    }

    public void newTask(View view) {
        if (titleEditTExt.getText().toString().isEmpty()) {
            titleEditTExt.setError("Título requerido");
        } else {
            //Se inserta la nueva tarea
            int idProject = getIntent().getIntExtra("projectId", 0);
            if(null != task){
                //Modificamos la tarea
                boolean execute = timeTrackerHelper.updateTask(titleEditTExt.getText().toString(), descriptionEditText.getText().toString(), task.getIdTask());
                if(execute){
                    Toast.makeText(this,"Se ha modificado la tarea", Toast.LENGTH_SHORT).show();
                    startTaskListActivity(idProject);
                }
            }else{
                task = timeTrackerHelper.insertTask(titleEditTExt.getText().toString(), descriptionEditText.getText().toString(), idProject);
                Toast.makeText(this, "Tarea creada", Toast.LENGTH_SHORT).show();
                startTaskListActivity(idProject);
            }
        }
    }

    private void startTaskListActivity(int projectId){
        Intent intent = new Intent(this, TaskListActivity.class);
        intent.putExtra("task", task.getIdTask());
        intent.putExtra("projectId", projectId);
        startActivity(intent);
    }


    @Override
    public void onClick(View v) {
        int idProject = getIntent().getIntExtra("projectId", 0);
        if(executing){
            timeTrackerHelper.stopTask(task.getIdTask());
        }else{
            timeTrackerHelper.executeTask(task.getIdTask());
        }
        startTaskListActivity(idProject);
    }


    public void back(View view){
        Intent intent = new Intent(this, TaskListActivity.class);
        int idProject = getIntent().getIntExtra("projectId", 0);
        intent.putExtra("projectId", idProject);
        startActivity(intent);
    }

    public void logout(View view){
        ((GlobalState)getApplication()).setSessionUser(null);
        Intent intent = new Intent(this, MainActivity.class);
        startActivity(intent);
    }
}
