package es.androidcurso.timetracker.adapter;

import android.app.Activity;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import org.w3c.dom.Text;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Vector;
import java.util.concurrent.TimeUnit;

import es.androidcurso.timetracker.R;
import es.androidcurso.timetracker.entities.Project;
import es.androidcurso.timetracker.entities.Task;
import es.androidcurso.timetracker.sqlite.TimeTrackerHelper;

/**
 * Created by Usuario on 12/09/2015.
 */
public class ProjectAdapter extends BaseAdapter {

    private final Activity activity;
    private final List<Project> lista;

    public ProjectAdapter(Activity activity, List<Project> lista){
        super();
        this.activity = activity;
        this.lista = lista;
    }


    @Override
    public int getCount() {
        return lista.size();
    }

    @Override
    public Object getItem(int position) {
        return lista.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }


    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        LayoutInflater inflater = activity.getLayoutInflater();
        View view = inflater.inflate(R.layout.list_element, null, true);
        Project project = lista.get(position);
        TextView textView = (TextView) view.findViewById(R.id.titulo);
        String iniDate = project.getIniDate();
        textView.setText(project.getTitle().concat(" (").concat(iniDate).concat(")"));
        TextView hoursView = (TextView) view.findViewById(R.id.estimatedHours);
        hoursView.setText("Horas estimadas: ".concat(String.valueOf(project.getEstimatedHours())));
        TextView totalHoursView = (TextView) view.findViewById(R.id.totalHours);

        TimeTrackerHelper helper = new TimeTrackerHelper(activity);
        List<Task> taskList = helper.getProjectTasks(project.getIdProject());
        long totalTime = 0;
        for(Task task: taskList){
            long time = helper.getTaskTime(task.getIdTask());
            totalTime = totalTime + time;
        }


        String time = String.format("%d hora, %d minutos",
                TimeUnit.MILLISECONDS.toHours(totalTime),
                TimeUnit.MILLISECONDS.toMinutes(totalTime) -
                        TimeUnit.HOURS.toMinutes(TimeUnit.MILLISECONDS.toHours(totalTime)));
        totalHoursView.setText("Horas consumidas: ".concat(time));

        int hours = Integer.valueOf(String.valueOf(TimeUnit.MILLISECONDS.toHours(totalTime)));

        if(hours > project.getEstimatedHours()){
            view.setBackgroundColor(Color.RED);
        }else{
            view.setBackgroundColor(view.getResources().getColor(R.color.background_green));
        }
        view.setMinimumHeight(100);
        view.setPadding(0,5,0,0);
        view.invalidate();
        return view;
    }
}
