package es.androidcurso.timetracker.adapter;

import android.app.Activity;
import android.graphics.Color;
import android.media.Image;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import java.util.List;
import java.util.concurrent.TimeUnit;

import es.androidcurso.timetracker.R;
import es.androidcurso.timetracker.entities.Project;
import es.androidcurso.timetracker.entities.Task;
import es.androidcurso.timetracker.sqlite.TimeTrackerHelper;

/**
 * Created by Usuario on 12/09/2015.
 */
public class TaskAdapter extends BaseAdapter {

    private final Activity activity;
    private final List<Task> taskList;

    public TaskAdapter(Activity activity, List<Task> taskList){
        super();
        this.activity = activity;
        this.taskList = taskList;
    }


    @Override
    public int getCount() {
        return taskList.size();
    }

    @Override
    public Object getItem(int position) {
        return taskList.get(position);
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        LayoutInflater inflater = activity.getLayoutInflater();
        View view = inflater.inflate(R.layout.task_list_element, null, true);
        Task task = taskList.get(position);
        TextView textView = (TextView) view.findViewById(R.id.titulo);
        textView.setText(task.getTitle());
        TextView descView = (TextView) view.findViewById(R.id.descripcion);
        descView.setText(taskList.get(position).getDescription());

        TimeTrackerHelper helper = new TimeTrackerHelper(activity);
        long totalTime = helper.getTaskTime(task.getIdTask());

        String time = String.format("%d hora, %d minutos",
                TimeUnit.MILLISECONDS.toHours(totalTime),
                TimeUnit.MILLISECONDS.toMinutes(totalTime) -
                        TimeUnit.HOURS.toMinutes(TimeUnit.MILLISECONDS.toHours(totalTime)));

        TextView totalHours = (TextView) view.findViewById(R.id.totalHours);
        totalHours.setText("Horas consumidas: ".concat(String.valueOf(time)));

        TimeTrackerHelper timeTrackerHelper = new TimeTrackerHelper(activity);
        boolean execution = timeTrackerHelper.isTaskExecuting(task.getIdTask());

        ImageView image = (ImageView) view.findViewById(R.id.taskIco);
        if(execution){
            image.setImageResource(R.drawable.played);
        }else{
            image.setImageResource(R.drawable.stopped);

        }

        return view;
    }
}
