package es.androidcurso.timetracker.sqlite;

import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.widget.Toast;


import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

import es.androidcurso.timetracker.entities.Project;
import es.androidcurso.timetracker.entities.Scheduling;
import es.androidcurso.timetracker.entities.Task;
import es.androidcurso.timetracker.entities.User;

/**
 * Created by Usuario on 25/10/2015.
 */
public class TimeTrackerHelper extends SQLiteOpenHelper {

    private Context context;

    public TimeTrackerHelper(Context context) {
        super(context, "time_tracker", null, 2);
        this.context = context;
    }

    @Override
    public void onCreate(SQLiteDatabase db) {
        try {
            db.execSQL("CREATE TABLE user (" +
                    "userId INTEGER PRIMARY KEY AUTOINCREMENT, " +
                    "name TEXT, password TEXT, email TEXT)");
            db.execSQL("CREATE TABLE project (" +
                    "projectId INTEGER PRIMARY KEY AUTOINCREMENT, " +
                    "title TEXT, estimatedHours INT, totalHours INT, iniDate TEXT, endDate TEXT, user INTEGER, " +
                    "FOREIGN KEY (user) REFERENCES user (userId))");
            db.execSQL("CREATE TABLE task (" +
                    "taskId INTEGER PRIMARY KEY AUTOINCREMENT, " +
                    "title TEXT, description TEXT, project INTEGER, " +
                    "FOREIGN KEY (project) REFERENCES project (projectId))");
            db.execSQL("CREATE TABLE scheduling (" +
                    "schedulingId INTEGER PRIMARY KEY AUTOINCREMENT, " +
                    "iniDate TEXT, endDate TEXT, " +
                    "task INTEGER, FOREIGN KEY (task) REFERENCES task (taskId))");
        } catch (Exception ex) {
            System.out.print(ex.getMessage());
        }

    }

    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
    }

    public User searchUser(String name, String password) {
        User user = null;
        try {
            SQLiteDatabase db = getWritableDatabase();
            Cursor cursor = db.rawQuery("SELECT * FROM user "
                    + "WHERE name='" + name + "' and password='" + password + "'", null);
            if (cursor.moveToNext()) {
                int idUser = cursor.getInt(0);
                String email = cursor.getString(3);
                cursor.close();
                user = new User(idUser, name, password, email);
                return user;
            }
            return null;
        } catch (Exception ex) {
            System.out.print(ex);
        }
        return user;
    }

    public Task searchTask(String title, int project) {
        Task task = null;
        try {
            SQLiteDatabase db = getWritableDatabase();
            Cursor cursor = db.rawQuery("SELECT * FROM task "
                    + "WHERE title='" + title + "' and project='" + project + "'", null);
            if (cursor.moveToNext()) {
                int idTask = cursor.getInt(0);
                String description = cursor.getString(2);
                task = new Task(idTask, title, description);
            }
        } catch (Exception ex) {
            System.out.print(ex);
        }
        return task;
    }

    public Project searchProject(String title, int user) {
        Project project = null;
        try {
            SQLiteDatabase db = getWritableDatabase();
            Cursor cursor = db.rawQuery("SELECT * FROM project "
                    + "WHERE title='" + title + "' and user='" + user + "'", null);
            if (cursor.moveToNext()) {
                int idProject = cursor.getInt(0);
                Integer estimatedHours = cursor.getInt(2);
                Integer totalHours = cursor.getInt(3);
                String iniDate = cursor.getString(4);
                String endDate = cursor.getString(5);
                project = new Project(idProject, title, iniDate, estimatedHours);
                if (null != totalHours) {
                    project.setTotalHours(totalHours);
                }
                if (null != endDate) {
                    project.setEndDate(endDate);
                }
            }
        } catch (Exception ex) {
            System.out.print(ex);
        }
        return project;
    }

    public Project findProjectById(int idProject) {
        Project project = null;
        try {
            SQLiteDatabase db = getWritableDatabase();
            Cursor cursor = db.rawQuery("SELECT * FROM project "
                    + "WHERE projectId='" + idProject + "'", null);
            if (cursor.moveToNext()) {
                String title = cursor.getString(1);
                Integer estimatedHours = cursor.getInt(2);
                Integer totalHours = cursor.getInt(3);
                String iniDate = cursor.getString(4);
                String endDate = cursor.getString(5);
                project = new Project(idProject, title, iniDate, estimatedHours);
                if (null != totalHours) {
                    project.setTotalHours(totalHours);
                }
                if (null != endDate) {
                    project.setEndDate(endDate);
                }
            }
        } catch (Exception ex) {
            System.out.print(ex);
        }
        return project;
    }



    public User insertUser(String login, String password, String email) {
        User user = null;
        SQLiteDatabase db = getWritableDatabase();
        Cursor cursor = db.rawQuery("SELECT userId FROM user "
                + "WHERE name='" + login + "'", null);
        if (cursor.moveToNext()) {
            Toast.makeText(context, "Ya existe un usuario con ese nombre", Toast.LENGTH_SHORT).show();
        } else {
            try {
                db.execSQL("INSERT INTO user VALUES (null, '" + login
                        + "','" + password + "', '" + email + "')");
                cursor.close();
                user = this.searchUser(login, password);
            } catch (Exception ex) {
                Toast.makeText(context, "Se ha producido un error al regisrar el usuario", Toast.LENGTH_SHORT).show();
            }
        }
        return user;
    }

    public Project insertProject(String title, int estimatedHours, int userId) {
        Project project = null;
        SQLiteDatabase db = getWritableDatabase();
        Cursor cursor = db.rawQuery("SELECT projectId FROM project "
                + "WHERE title='" + title + "' and user='" + userId + "'", null);
        if (cursor.moveToNext()) {
            Toast.makeText(context, "Ya existe un proyecto con ese título", Toast.LENGTH_SHORT).show();
        } else {
            try {
                Date iniDate = Calendar.getInstance().getTime();
                SimpleDateFormat f = new SimpleDateFormat("dd-MM-yyyy");
                String ini = f.format(iniDate);
                db.execSQL("INSERT INTO project VALUES (null, '" + title
                        + "', '" + estimatedHours + "', null,'" + ini + "',null,'" + userId + "')");
                cursor.close();
                project = this.searchProject(title, userId);
            } catch (Exception ex) {
                Toast.makeText(context, "Se ha producido un error al crear el proyecto", Toast.LENGTH_SHORT).show();
            }
        }
        return project;
    }

    public Task insertTask(String title, String description, int projectId) {
        Task task = null;
        SQLiteDatabase db = getWritableDatabase();
        Cursor cursor = db.rawQuery("SELECT taskId FROM task "
                + "WHERE title='" + title + "' and project='" + projectId + "'", null);
        if (cursor.moveToNext()) {
            Toast.makeText(context, "Ya existe una tarea con ese título", Toast.LENGTH_SHORT).show();
        } else {
            try {
                db.execSQL("INSERT INTO task VALUES (null, '" + title
                        + "','" + description + "','" + projectId + "')");
                cursor.close();
                task = this.searchTask(title, projectId);
            } catch (Exception ex) {
                Toast.makeText(context, "Se ha producido un error al crear la tarea", Toast.LENGTH_SHORT).show();
            }
        }
        return task;
    }

    public boolean executeTask(int idTask) {
        boolean execute = false;
        SQLiteDatabase db = getWritableDatabase();
        try {
            SimpleDateFormat f = new SimpleDateFormat("dd-MM-yyyy HH:mm");
            String iniDate = f.format(Calendar.getInstance().getTime());
            db.execSQL("INSERT INTO scheduling VALUES (null, '" + iniDate + "',null,'" + idTask
                    + "')");
            execute = true;
        } catch (Exception ex) {
            Toast.makeText(context, "Se ha producido un error al ejecutar la tarea", Toast.LENGTH_SHORT).show();
        }
        return execute;
    }

    public boolean updateProject(String title, int estimatedHours, int idProject) {
        boolean execute = false;
        SQLiteDatabase db = getWritableDatabase();
        try {
            db.execSQL("UPDATE project set title ='" + title + "',estimatedHours='" + estimatedHours + "' WHERE projectId='" + idProject + "'");
            execute = true;
        } catch (Exception ex) {
            Toast.makeText(context, "Se ha producido un error al modificar el proyecto", Toast.LENGTH_SHORT).show();
        }
        return execute;
    }

    public boolean updateTask(String title, String description, int idTask) {
        boolean execute = false;
        SQLiteDatabase db = getWritableDatabase();
        try {
            db.execSQL("UPDATE task set title ='" + title + "',description='" + description + "' WHERE taskId='" + idTask + "'");
            execute = true;
        } catch (Exception ex) {
            Toast.makeText(context, "Se ha producido un error al modificar la tarea", Toast.LENGTH_SHORT).show();
        }
        return execute;
    }

    public boolean stopTask(int idTask) {
        boolean execute = false;
        SQLiteDatabase db = getWritableDatabase();
        try {
            SimpleDateFormat f = new SimpleDateFormat("dd-MM-yyyy HH:mm");
            String endDate = f.format(Calendar.getInstance().getTime());
            db.execSQL("UPDATE scheduling set endDate='" + endDate + "' WHERE task ='"+idTask+"' and endDate IS NULL");
            execute = true;

        } catch (Exception ex) {
            Toast.makeText(context, "Se ha producido un error al parar la tarea", Toast.LENGTH_SHORT).show();
        }
        return execute;
    }

    public long getTaskTime(int idTask) {
        long totalTime = 0;
        try {
            SQLiteDatabase db = getWritableDatabase();
            Cursor cursor = db.rawQuery("SELECT * FROM scheduling "
                    + "WHERE task='" + idTask + "' and endDate IS NOT NULL order by schedulingId ASC", null);
            SimpleDateFormat f = new SimpleDateFormat("dd-MM-yyyy HH:mm");
            while (cursor.moveToNext()) {
                String iniDate = cursor.getString(1);
                long iniTime = f.parse(iniDate).getTime();
                String endDate = cursor.getString(2);
                long endTime = f.parse(endDate).getTime();
                totalTime = totalTime + (endTime - iniTime);
            }
            cursor = db.rawQuery("SELECT * FROM scheduling "
                    + "WHERE task='" + idTask + "' and endDate IS NULL", null);
            while (cursor.moveToNext()) {
                String iniDate = cursor.getString(1);
                long iniTime = f.parse(iniDate).getTime();
                long endTime = Calendar.getInstance().getTimeInMillis();
                totalTime = totalTime + (endTime - iniTime);
            }
        } catch (Exception ex) {
            System.out.print(ex);
        }
        return totalTime;
    }

    public List<Project> getUserProjects(int idUser) {
        SQLiteDatabase db = getWritableDatabase();
        Cursor cursor = db.rawQuery("SELECT * FROM project "
                + "WHERE user='" + idUser + "'", null);
        List<Project> projectList = new ArrayList<>();
        while (cursor.moveToNext()) {
            int idProject = cursor.getInt(0);
            String title = cursor.getString(1);
            Integer estimatedHours = cursor.getInt(2);
            Integer totalHours = cursor.getInt(3);
            String iniDate = cursor.getString(4);
            String endDate = cursor.getString(5);
            Project project = new Project(idProject, title, iniDate, estimatedHours);
            if (null != totalHours) {
                project.setTotalHours(totalHours);
            }
            if (null != endDate) {
                project.setEndDate(endDate);
            }
            projectList.add(project);
        }
        cursor.close();
        return projectList;
    }

    public List<Task> getProjectTasks(int idProject) {
        SQLiteDatabase db = getWritableDatabase();
        Cursor cursor = db.rawQuery("SELECT * FROM task "
                + "WHERE project='" + idProject + "'", null);
        List<Task> taskList = new ArrayList<>();
        while (cursor.moveToNext()) {
            int idTask = cursor.getInt(0);
            String title = cursor.getString(1);
            String description = cursor.getString(2);
            Task task = new Task(idTask, title, description);
            taskList.add(task);
        }
        cursor.close();
        return taskList;
    }

    public boolean isTaskExecuting(int idTask) {
        boolean executing = false;
        SQLiteDatabase db = getWritableDatabase();
        Cursor cursor = db.rawQuery("SELECT * FROM scheduling "
                + "WHERE task='" + idTask + "' ORDER BY schedulingId DESC limit 1", null);
        if (cursor.moveToNext()) {
            String endDate = cursor.getString(2);
            if (null == endDate) {
                executing = true;
            }
        }
        return executing;
    }
}